P300 Speller — BCI-Framework documentation

# P300 Speller

Implemented through extensions systems in the P300Speller module.

The interface layout of the speller followed the typical design of a row-column speller. The six rows and six columns were configured with 36 symbols (A to Z, 0 to 9). Each symbol was presented equally spaced. The stimulus-time interval can be setted between 100 and 500 ms, and the inter-stimulus interval (ISI) between 0 and 300 ms. A single iteration of stimulus presentation in all rows and columns was considered a sequence. Therefore, one sequence consisted of 12 stimulus flashes. A maximum of 15 sequences (i.e., 180 flashes) was allotted without prolonged inter-sequence intervals for each target character. After the end of selected number sequences (5 by default), 3 s were given to the user for identifying, locating, and gazing at the next target character. The participant can be instructed to attend to the target symbol by counting the number of times each target character had been flashed 1.

## Configuration options

Trials:
Number of targets to use in the run. 5 targets by default.
Target notice:
Time used to show to the subject the target that must focus on.
Flash duration:
Stimuli duration in miliseconds. 125 ms by default.
Inter stimulus interval:
Time between flashes. 62.5 ms by default.

## Feedback mode

In feedback mode, the stimuli delivery is working constantly. In the background, an online classifier is checking for the presence of ERP and returning the corresponding value.

### References

1

  Min-Ho Lee, O-Yeon Kwon, Yong-Jeong Kim, Hong-Kyung Kim, Young-Eun Lee, John Williamson, Siamac Fazli, and Seong-Whan Lee. Eeg dataset and openbmi toolbox for three bci paradigms: an investigation into bci illiteracy. GigaScience, 8(5):giz002, 2019.